aboutsummaryrefslogtreecommitdiffstats
path: root/fetchmail.h
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>2001-06-12 13:54:34 +0000
committerEric S. Raymond <esr@thyrsus.com>2001-06-12 13:54:34 +0000
commitc6d40e5347619bfd246bef4e3ded59ed61f88353 (patch)
tree54a61e8621dac4a657b6a91820db1ede735a175b /fetchmail.h
parent7fed81d3a579bae6712f99a16512c97721f0ee21 (diff)
downloadfetchmail-c6d40e5347619bfd246bef4e3ded59ed61f88353.tar.gz
fetchmail-c6d40e5347619bfd246bef4e3ded59ed61f88353.tar.bz2
fetchmail-c6d40e5347619bfd246bef4e3ded59ed61f88353.zip
Break driver.c in half.
svn path=/trunk/; revision=3339
Diffstat (limited to 'fetchmail.h')
-rw-r--r--fetchmail.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/fetchmail.h b/fetchmail.h
index f6e397ba..a62751b7 100644
--- a/fetchmail.h
+++ b/fetchmail.h
@@ -321,6 +321,7 @@ struct msgblk /* message header parsed for open_sink() */
char *headers; /* raw message headers */
struct idlist *recipients; /* addressees */
char return_path[HOSTLEN + USERNAMELEN + 4];
+ int msglen;
int reallen;
};
@@ -403,8 +404,15 @@ void report_complete ();
void report_at_line ();
#endif
-/* driver.c: transaction support */
+/* transact.c: transaction support */
+void init_transact(const struct method *);
void set_timeout(int);
+int readheaders(int sock,
+ long fetchlen,
+ long reallen,
+ struct query *ctl,
+ int num);
+int readbody(int sock, struct query *ctl, flag forward, int len);
#if defined(HAVE_STDARG_H)
void gen_send (int sock, const char *, ... );
int gen_recv(int sock, char *buf, int size);
@@ -414,6 +422,7 @@ void gen_send ();
int gen_recv();
int gen_transact ();
#endif
+extern struct msgblk msgblk;
/* lock.c: concurrency locking */
void lock_setup(void), lock_assert(void);